{% extends "admin/base_site.html" %}

<!-- LOADING -->
{% load i18n admin_urls %}

<!-- BREADCRUMBS -->
{% block breadcrumbs %}
<div class="breadcrumbs">
     <a href="../../../../">{% trans "Home" %}</a> &rsaquo;
     <a href="../../../">{{ app_label|capfirst }}</a> &rsaquo;
     <a href="../../">{{ opts.verbose_name_plural|capfirst }}</a> &rsaquo;
     <a href="../">{{ object|truncatewords:"18" }}</a> &rsaquo;
     {% trans 'Delete' %}
</div>
{% endblock %}

<!-- CONTENT -->
{% block content %}
{% if perms_lacking or protected %}
    {% if perms_lacking %}
        <p>{% blocktrans with object as escaped_object %}Deleting the {{ object_name }} '{{ escaped_object }}' would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}</p>
        <ul>
        {% for obj in perms_lacking %}
            <li>{{ obj }}</li>
        {% endfor %}
        </ul>
    {% endif %}
    {% if protected %}
        <p>{% blocktrans with object as escaped_object %}Deleting the {{ object_name }} '{{ escaped_object }}' would require deleting the following protected related objects:{% endblocktrans %}</p>
        <ul>
        {% for obj in protected %}
            <li>{{ obj }}</li>
        {% endfor %}
        </ul>
    {% endif %}
{% else %}
    <p>{% blocktrans with object as escaped_object %}Are you sure you want to delete the {{ object_name }} "{{ escaped_object }}"? All of the following related items will be deleted:{% endblocktrans %}</p>
    <ul>{{ deleted_objects|unordered_list }}</ul>
    <form action="" method="post">{% csrf_token %}
        <div class="submit-row">
            {% url opts|admin_urlname:'change' object.pk|admin_urlquote as object_url %}
            <p class="cancellink-box"><a href="{% add_preserved_filters object_url %}" class="cancellink">{% trans "Cancel" %}</a></p>
            <input type="hidden" name="post" value="yes" />
            <input type="submit" value="{% trans "Yes, I'm sure" %}" class="default" />
        </div>
    </form>
{% endif %}
{% endblock %}
